@@ -1,7 +1,7 @@
 mod common;
 
 use anyhow::Result;
-use assert_cmd::Command;
+use assert_cmd::{cargo_bin, Command};
 use common::create_test_files;
 use predicates::prelude::*;
 use predicates::str::contains;
@@ -9,7 +9,7 @@ use predicates::str::contains;
 #[test]
 fn test_simple_infer_lang() -> Result<()> {
   let dir = create_test_files([("a.ts", "console.log(123)"), ("b.rs", "console.log(456)")])?;
-  Command::cargo_bin("ast-grep")?
+  Command::new(cargo_bin!())
     .current_dir(dir.path())
     .args(["-p", "console.log($A)"])
     .assert()
@@ -22,7 +22,7 @@ fn test_simple_infer_lang() -> Result<()> {
 #[test]
 fn test_simple_specific_lang() -> Result<()> {
   let dir = create_test_files([("a.ts", "console.log(123)"), ("b.rs", "console.log(456)")])?;
-  Command::cargo_bin("ast-grep")?
+  Command::new(cargo_bin!())
     .current_dir(dir.path())
     .args(["-p", "console.log($A)", "-l", "rs"])
     .assert()
@@ -38,7 +38,7 @@ fn test_js_in_html() -> Result<()> {
     ("a.html", "<script>alert(1)</script>"),
     ("b.js", "alert(456)"),
   ])?;
-  Command::cargo_bin("ast-grep")?
+  Command::new(cargo_bin!())
     .current_dir(dir.path())
     .args(["-p", "alert($A)", "-l", "js"])
     .assert()
@@ -51,7 +51,7 @@ fn test_js_in_html() -> Result<()> {
 #[test]
 fn test_rewrite_js_in_html() -> Result<()> {
   let dir = create_test_files([("a.html", "<script>alert(1)</script>")])?;
-  Command::cargo_bin("ast-grep")?
+  Command::new(cargo_bin!())
     .current_dir(dir.path())
     .args(["-p", "alert($A)", "-r", "alert(456)"])
     .assert()
@@ -64,7 +64,7 @@ fn test_rewrite_js_in_html() -> Result<()> {
 #[test]
 fn test_inspect() -> Result<()> {
   let dir = create_test_files([("a.js", "alert(1)"), ("b.js", "alert(456)")])?;
-  Command::cargo_bin("ast-grep")?
+  Command::new(cargo_bin!())
     .current_dir(dir.path())
     .args(["-p", "alert($A)", "-l", "js", "--inspect", "entity"])
     .assert()
@@ -77,7 +77,7 @@ fn test_inspect() -> Result<()> {
 #[test]
 fn test_status_code_fail_with_no_match() -> Result<()> {
   let dir = create_test_files([("a.js", "alert(1)")])?;
-  Command::cargo_bin("ast-grep")?
+  Command::new(cargo_bin!())
     .current_dir(dir.path())
     .args(["-p", "no-match"])
     .assert()
@@ -89,7 +89,7 @@ fn test_status_code_fail_with_no_match() -> Result<()> {
 #[test]
 fn test_debug_query() -> Result<()> {
   // should not print pattern if invalid
-  Command::cargo_bin("ast-grep")?
+  Command::new(cargo_bin!())
     .args(["-p", "foo;bar;", "-l", "js", "--debug-query"])
     .assert()
     .failure()
@@ -97,7 +97,7 @@ fn test_debug_query() -> Result<()> {
     .stderr(contains("Cannot parse query as a valid pattern"));
 
   // should  print debug tree even for invalid pattern
-  Command::cargo_bin("ast-grep")?
+  Command::new(cargo_bin!())
     .args(["-p", "foo;bar;", "-l", "js", "--debug-query=ast"])
     .assert()
     .failure()
@@ -110,7 +110,7 @@ fn test_debug_query() -> Result<()> {
 #[test]
 fn test_unsupport_config_arg() -> Result<()> {
   let dir = create_test_files([])?;
-  Command::cargo_bin("ast-grep")?
+  Command::new(cargo_bin!())
     .current_dir(dir.path())
     .args(["-p", "alert($A)", "-c", "not-found.yml"])
     .assert()
@@ -122,7 +122,7 @@ fn test_unsupport_config_arg() -> Result<()> {
 #[test]
 fn test_trace_default_project() -> Result<()> {
   let dir = create_test_files([("sgconfig.yml", "ruleDirs: []")])?;
-  Command::cargo_bin("ast-grep")?
+  Command::new(cargo_bin!())
     .current_dir(dir.path())
     .args(["-p", "alert($A)", "--inspect=summary"])
     .assert()
@@ -134,13 +134,13 @@ fn test_trace_default_project() -> Result<()> {
 #[test]
 fn test_trace_project() -> Result<()> {
   let dir = create_test_files([("not.yml", "ruleDirs: []")])?;
-  Command::cargo_bin("ast-grep")?
+  Command::new(cargo_bin!())
     .current_dir(dir.path())
     .args(["-p", "alert($A)", "--inspect=summary"])
     .assert()
     .failure()
     .stderr(contains("isProject=false"));
-  Command::cargo_bin("ast-grep")?
+  Command::new(cargo_bin!())
     .current_dir(dir.path())
     .args(["run", "-c=not.yml", "-p", "alert($A)", "--inspect=summary"])
     .assert()
